@@ -1039,32 +1039,36 @@ def CreateImagenetLoaders(s3, s3def, src, dest, bucket = None, width=256, height
 
     # Load dataset
     if loaders is None:
-        transform_list = []
-        #transform_list.append(transforms.Resize(size=max(width,height)-1,max_size=max(width,height)))
-        transform_list.append(ResizePad(width, height))
-        transform_list.append(transforms.RandomHorizontalFlip(p=0.5))
-        if rotate > 0 or offset > 0 or scale_min != 1.0 or scale_max != 1.0:
-            transform_list.append(transforms.RandomAffine(degrees=rotate,
-                    translate=(offset, offset), 
-                    scale=(scale_min, scale_max), 
-                    interpolation=transforms.InterpolationMode.BILINEAR))
-        transform_list.append(transforms.RandomCrop( (width, height), padding=None, pad_if_needed=True, fill=0, padding_mode='constant'))
-        transform_list.append(transforms.ToTensor())
-        transform_list.append(transforms.Normalize((0.0, 0.0, 0.0), (1.0, 1.0, 1.0))) # Imagenet mean and standard deviation
-        if augment_noise > 0.0:
-            transform_list.append(AddGaussianNoise(0., augment_noise))
+        if normalize:
+            transform_list = []
+            #transform_list.append(transforms.Resize(size=max(width,height)-1,max_size=max(width,height)))
+            transform_list.append(ResizePad(width, height))
+            transform_list.append(transforms.RandomHorizontalFlip(p=0.5))
+            if rotate > 0 or offset > 0 or scale_min != 1.0 or scale_max != 1.0:
+                transform_list.append(transforms.RandomAffine(degrees=rotate,
+                        translate=(offset, offset), 
+                        scale=(scale_min, scale_max), 
+                        interpolation=transforms.InterpolationMode.BILINEAR))
+            transform_list.append(transforms.RandomCrop( (width, height), padding=None, pad_if_needed=True, fill=0, padding_mode='constant'))
+            transform_list.append(transforms.ToTensor())
+            transform_list.append(transforms.Normalize((0.0, 0.0, 0.0), (1.0, 1.0, 1.0))) # Imagenet mean and standard deviation
+            if augment_noise > 0.0:
+                transform_list.append(AddGaussianNoise(0., augment_noise))
 
-        train_transform = transforms.Compose(transform_list)
+            train_transform = transforms.Compose(transform_list)
 
-        test_transform = transforms.Compose([
-            ResizePad(width, height),
-            transforms.RandomCrop( (width, height), padding=None, pad_if_needed=True, fill=0, padding_mode='constant'),
-            transforms.ToTensor(), 
-            transforms.Normalize((0.0, 0.0, 0.0), (1.0, 1.0, 1.0)) # Imagenet mean and standard deviation
-        ])
+            test_transform = transforms.Compose([
+                ResizePad(width, height),
+                transforms.RandomCrop( (width, height), padding=None, pad_if_needed=True, fill=0, padding_mode='constant'),
+                transforms.ToTensor(), 
+                transforms.Normalize((0.0, 0.0, 0.0), (1.0, 1.0, 1.0)) # Imagenet mean and standard deviation
+            ])
+        else:
+            train_transform = None
+            test_transform = None
 
         default_loaders = [{'set':'train', 'dataset': dest, 'enable_transform':True, 'transform':train_transform},
-                        {'set':'val', 'dataset': dest, 'enable_transform':False, 'transform':train_transform}]
+                        {'set':'val', 'dataset': dest, 'enable_transform':False, 'transform':test_transform}]
 
         loaders = default_loaders
 
